#include <msp430.h>
#include <stdint.h>
#include <stdbool.h>
#include "App.h"
#include "Gpio.h"
#include "System.h"

int main(void) {

  // Stop watchdog
  WDTCTL = WDTPW + WDTHOLD;

  // Select lowest DCOx and MODx settings
  DCOCTL = 0;
  // Set range
  BCSCTL1 = CALBC1_1MHZ;
  // Set DCO step + modulation
  DCOCTL = CALDCO_1MHZ;

  BCSCTL3 |= LFXT1S_2;
  P2SEL = 0;
  P2SEL2 = 0;

  // Make GPIOs input with pull down
  P1OUT = 0x00;
  P1REN = 0xff;
  P1DIR = 0x00;

  P2OUT = 0x00;
  P2REN = 0xff;
  P2DIR = 0x00;

  // P2.6 LED, low active
  BIT_SET(P2OUT, BIT6);
  BIT_CLEAR(P2REN, BIT6);
  BIT_SET(P2DIR, BIT6);

  // P1.2 INFO LED, high active
  BIT_CLEAR(P1OUT, BIT2);
  BIT_CLEAR(P1REN, BIT2);
  BIT_SET(P1DIR, BIT2);

  // Rising edge for IR detect signal (P2.7)
  BIT_CLEAR(P2IES, GPIO_IR_DETECT_PIN);
  BIT_CLEAR(P2SEL2, GPIO_IR_DETECT_PIN);
  BIT_CLEAR(P2SEL, GPIO_IR_DETECT_PIN);

  __bis_SR_register(GIE);

  while(1) {
    BIT_CLEAR(P2IES, GPIO_IR_DETECT_PIN);
    BIT_CLEAR(P2IFG, GPIO_IR_DETECT_PIN);
    BIT_SET(P2IE, GPIO_IR_DETECT_PIN);
    __bis_SR_register(LPM4_bits);

    // Interrupt has been detected, turn on LED for a second
    BIT_SET(P1OUT, BIT2);
    _delay_cycles(1000000);
    BIT_CLEAR(P1OUT, BIT2);
//    BIT_CLEAR(P2OUT, BIT6);
//    _delay_cycles(1000000);
//    BIT_SET(P2OUT, BIT6);
  }
}

#pragma vector=PORT2_VECTOR
__interrupt void Port2Isr(void) {

  switch (P2IFG) {

    case GPIO_IR_DETECT_PIN: {
      // Avoid getting stuck in here
      BIT_CLEAR(P2IE, GPIO_IR_DETECT_PIN);
      BIT_CLEAR(P2IFG, GPIO_IR_DETECT_PIN);
      __bic_SR_register_on_exit(LPM4_bits);
      break;
    }

    default: {
      break;
    }
  }
}
